# -*- coding: utf-8 -*-
""" publications table and associated widgets


"""
#-------------------------------------------------------------------------------
#
# DEFINITION
#
#-------------------------------------------------------------------------------
tp_authors = \
"""List of authors separated by commma: J. Doe, P.-Y. Smith
For large collaboration the first author followed by et al.: J. Doe et al."""

tp_authors_cppm = \
"""List of authors separated by comma: P.-Y. Doe, J. Smith"""

tp_first = "first page"

tp_last = "last_page"

tp_report_numbers = \
"""List of report identifier separated by comma: 
LHCb-PROC-2008-04, arXiv:0906.1516 """
 
tp_speaker = \
"""The name of the speaker: P.-Y. Smith"""

db.define_table("publications",
    Field("title", "text", notnull=True),
    Field("authors", "string", notnull=True, comment=tp_authors),
    Field("id_collaborations", 'reference collaborations', default=undef_id, label="Collaboration"),
    Field("id_publishers", 'reference publishers', default=undef_id,  label="Publisher"),
    Field("year", "integer", notnull=True, default=year, requires=IS_INT_IN_RANGE(1900, year+1)),
    Field("doi", "string"),
    Field("volume", "integer", requires=IS_EMPTY_OR(IS_INT_IN_RANGE(1, None))),
    Field("first_page", "integer", requires=IS_EMPTY_OR(IS_INT_IN_RANGE(1, None)), comment=tp_first),
    Field("last_page", "integer", requires=IS_EMPTY_OR(IS_INT_IN_RANGE(1, None)), comment=tp_last),
    Field("e_print", "string", requires=IS_EMPTY_OR(IS_URL())),
    Field("conference_title", "text", label='Title'),
    Field("conference_url", "string", label='url', requires=IS_EMPTY_OR(IS_URL())),
    Field("conference_start", "date", label='Start date'),
    Field("conference_end", "date", label='End date'),
    Field("conference_town", "string", label='Town'),
    Field("id_countries", 'reference countries', default=undef_id, label='Country'),
    Field("conference_speaker", "string", label='Speaker', comment=tp_speaker),
    Field("report_numbers", "string", comment=tp_report_numbers),
    Field("id_reports", 'reference reports', default=undef_id, label="Report type"),
    Field("authors_cppm", "text", notnull=True, comment=tp_authors_cppm),
    Field("id_teams", 'reference teams', default=undef_id, label='Team'),
    Field("id_projects", 'reference projects', default=undef_id, label='Projects'),
    Field("id_categories", 'reference categories', default=undef_id, label='AERES'),
    migrate="publications.table")

db.publications.id_categories.requires = \
IS_IN_DB(db, 'categories.id', 'categories.code')

db.publications.id_collaborations.requires = \
IS_IN_DB(db, 'collaborations.id', 'collaborations.collaboration')

db.publications.id_countries.requires = \
IS_IN_DB(db, 'countries.id', 'countries.country')

db.publications.id_publishers.requires = \
IS_IN_DB(db, 'publishers.id', 'publishers.abbreviation')

db.publications.id_projects.requires = \
IS_IN_DB(db, 'projects.id', 'projects.project')

db.publications.id_reports.requires = \
IS_IN_DB(db, 'reports.id', 'reports.type')

db.publications.id_teams.requires = \
IS_IN_DB(db, 'teams.id', 'teams.team')

#-------------------------------------------------------------------------------
#
# STORE CONFIGURATiON
#
#-------------------------------------------------------------------------------

#-------------------------------------------------------------------------------
#
# FIELDS CONFIGURATiON
#
#-------------------------------------------------------------------------------
fieldsModifier = dbui.FieldsModifier('publications')
fieldsModifier.configure_field('conference_start', format='Y-m-d')
fieldsModifier.configure_field('conference_end', format='Y-m-d')
fieldsModifier.configure_field('year', maxValue=datetime.now().year)
  
fieldsModifier.merge_fields('first_page', 
                            'last_page',
                            fieldLabel=T('Pages'))
  
fieldsModifier.merge_fields('conference_start',
                            'conference_end',
                            fieldLabel=T('Dates'))

#-------------------------------------------------------------------------------
#
# FORM CONFIGURATiON
#
#-------------------------------------------------------------------------------
formModifier = dbui.FormModifier('publications')
formModifier.merge_fields('title',
                          'authors',
                          'id_collaborations',
                          'id_publishers',
                          'year',
                          'doi',
                          'volume',
                          'first_page',
                          'e_print',
                          title=T('General'))
 
formModifier.merge_fields('conference_title',
                          'conference_url',
                          'conference_start',
                          'conference_town',
                          'id_countries',
                          'conference_speaker',
                          title=T('Conference'))
 
formModifier.merge_fields('report_numbers', 
                          'id_reports',
                          title=T('Report'))
 
formModifier.merge_fields('authors_cppm',
                          'id_teams',
                          'id_projects',
                          'id_categories',
                          title='CPPM')

#
# Organise fieldSet within a TabPanel embedded in the publication form
#
formModifier.set_mapper(dbui.map_tabpanel)

#
# Polish the look and feel of the publication form
# NOTE: the width/height define the size of the window 
# when running the form from the grid. The defaults defines the height
# of the fieldSet allowing a fine tuning of the form layout.
#
formModifier.configure(buttonAlign='right',
                       labelWidth=100,
                       labelAlign='right',
                       width=400)

#-------------------------------------------------------------------------------
#
# GRID CONFIGURATiON
#
#-------------------------------------------------------------------------------
tpl = ['<b>{PublicationsTitle}</b><br>',
       '{PublicationsAuthors}',
       '<tpl if="PublicationsId_collaborations  &gt; 1">, {CollaborationsCollaboration}</tpl>',
       '<tpl if="PublicationsDoi">, {PublicationsDoi}</tpl>',
       '<tpl if="PublicationsId_publishers  &gt; 1">, {PublishersAbbreviation}',
           '<tpl if="PublicationsVolume"> {PublicationsVolume}</tpl>',
           '<tpl if="PublicationsYear"> ({PublicationsYear}) </tpl>',
           '<tpl if="PublicationsFirst_page"> {PublicationsFirst_page}</tpl>',
           '<tpl if="PublicationsLast_page">-{PublicationsLast_page}</tpl>',
       '</tpl>',
       '<tpl if="PublicationsConference_title"><br><br>{PublicationsConference_title}',
           '<tpl if="PublicationsConference_town"><br>{PublicationsConference_town}</tpl>',
           '<tpl if="CountriesCountry">, {CountriesCountry}</tpl>',
           '<tpl if="PublicationsConference_start">, {PublicationsConference_start}</tpl>',
           '<tpl if="PublicationsConference_end"> - {PublicationsConference_end}</tpl>',
           '<tpl if="PublicationsConference_url"><br>{PublicationsConference_url}</tpl>',
           '<br>%s: {PublicationsConference_speaker}' % T('Speaker'),
       '</tpl>',
       '<tpl if="PublicationsReport_numbers"><br><br>',
           '<tpl if="PublicationsId_reports &gt; 1">{ReportsType}, </tpl>',
           '{PublicationsReport_numbers}',
       '</tpl>'
       ]

gridModifier = dbui.GridModifier('publications')
gridModifier.configure(plugins=['pGridMathJax'])
gridModifier.merge_columns('title', 
                           'authors', 
                           'id_collaborations', 
                           'id_publishers',
                           'doi', 
                           'volume',
                           'first_page',
                           'last_page',
                           'conference_title',
                           'conference_url',
                           'conference_start',
                           'conference_end',
                           'conference_town',
                           'id_countries',
                           'conference_speaker',
                           'report_numbers',
                           'id_reports',
                           autohide=True,
                           header=T('Publication'),
                           position=0,
                           tpl=tpl,
                           width=700)

gridModifier.hide_columns('authors_cppm',
                          'e_print')

#
# Setup a filter panel for the publication grid
#

gridModifier.append_filter(('year', '==', T('select publication for a given year')))
gridModifier.append_filter(('id_teams', '==', T('select publications for a given team')))
gridModifier.append_filter(('id_projects', '==', T('select publications for a given project')))
gridModifier.append_filter(('id_categories', '==', T('select publications with a given category code')))
gridModifier.append_filter(('authors_cppm', 'contains', T('select publications for a given CPPM author')))
gridModifier.append_filter(('countries.country', 'contains', T('blab blab ....')))
 
gridModifier.configure_filters(plugins=['pFormToolTip'],
                               width=300)