/**
 * The Grid is an Ext.grid.Panel links to a database table.
 *
 * The store attribute is equal the table name when the widget is configured.
 * It is replaced by the App.data.DirectStore associated to the database
 * table in the initialization phase of the component.
 *
 * Many functionality can be added through plugins like the
 * App.grid.plugin.RowEditor, ....
 *
 */
Ext.define('App.grid.Panel', {

    extend: 'Ext.grid.Panel',
    alias: 'widget.xgrid',

    // private properties
    // Remote actions concern the filtering and the sorting of the store.
    // They are performed on the server side when true.
    // This condition depends on the grid properties and plugins.
    remoteAction: false,

    // predefined configuration options
    forceFit: true,

    // private method requests by the component model of ExtJS
    initComponent: function () {

        // link the grid to the data store
        this.store = App.getStore(this.store);

        // initialise the base class
        this.callParent(arguments);

        // Set the remote actions for the buffered store
        if (this.store.buffered) {
            this.store.getProxy().pageParam = 'page';
            this.remoteAction = true;
        }

        // Load the store.
        // this action depend on the grid properties and plugin.
        // At that step the plugins are not yet instantiate.
        // Thus wait the last moment.
        this.on('beforerender', this.onBeforeRender, this);
    },

    // Private method requires by the Ext JS component model
    beforeDestroy: function () {

        var i;

        // reset the store
        this.reset();

        // base class
        this.callParent(arguments);
    },

    // Private method call before the rendering to load the store.
    // The loading depends on the grid properties and plugins.
    // Thus we have to wait that all plugins are instantiate.
    //
    // @param {App.grid.Panel} grid
    // @param {Object} eOpts
    //
    onBeforeRender: function (grid, eOpts) {

        "use strict";

        if (this.remoteAction) {
            this.store.loadPage(1);

        } else if (!this.store.getTotalCount()) {
            this.store.load();
        }
    },

    /**
     * Reset the grid by removing filtering conditions
     * and by loading fresh data when the store is buffered.
     */
    reset: function () {

        "use strict";

        var store = this.getStore();

        if (this.remoteAction) {

            store.restoreWhere();
            store.data.clear(true);
            store.loadPage(1);

        } else {

            store.clearFilter();
            store.filter();
        }
    }
});
