/**
 * The plugin to render mathematics formula embedded in grid content.
 * The processing is performed by [MathJax](http://www.mathjax.org/).
 * The MathJax library is loaded by the framework
 *
 */
Ext.define('App.grid.plugin.MathJax', {

    extend: 'Ext.AbstractPlugin',
    alias: 'plugin.pGridMathJax',

    // Private attributes for internationalization
    textMask: 'Processing symbols',

    /**
     * Initialize the plugin
     *
     * @param {App.grid.Panel} grid
     *
     */
    init: function (grid) {

        "use strict";

        this.setCmp(grid);

        grid.getView().on('refresh', this.onProcessMath, this);
        grid.getStore().on('write', this.onProcessMath, this);
    },

    /**
     * destroy the plugin
     */
    destroy: function() {

        "use strict";

        var grid = this.getCmp();

        grid.getView().un('refresh', this.onProcessMath, this);
        grid.getStore().un('write', this.onProcessMath, this);
    },

    /**
     * Process maths objects
     *
     */
    onProcessMath: function () {

        "use strict";

        var grid = this.getCmp(),
            domEl = Ext.getDom(grid.getView().getEl()),
            loadMask;

        // mask the grid during MathJax processing
        loadMask = Ext.create('Ext.LoadMask', {
            target: grid,
            msg: this.textMask
        });

        loadMask.show();

        // push in the MatJax queue the processing followed by the unmasking
        MathJax.Hub.Queue(["Typeset", MathJax.Hub, domEl]);
        MathJax.Hub.Queue([function (mask) {mask.hide();}, loadMask]);
    }
});