/**
 * The plugin adding a message with the number of entries and the expert menu
 * in the bottom tool bar.
 *
 * **Note**: the pGridToolbar is ignored when both the pGridtoolbar
 * and the pGridPaging plugins are requested.
 *
 */
Ext.define('App.grid.plugin.Toolbar', {

    extend: 'Ext.AbstractPlugin',
    alias: 'plugin.pGridToolbar',

    // short cut
    bbar: null,

    // Private properties for internationalisation
    textEntries: 'Entries',
    textPlus: 'Plus',

    /**
     * Initialize the plugin
     *
     * @param {App.grid.Panel} grid
     *
     */
    init: function(grid) {

        "use strict";

        var menu,
            store = grid.getStore(),
            tableName = App.getTableName(store);

        // is pGridPaging ?
        if (App.isPlugin(grid, 'pGridPaging')) {
            return;
        }

        // keep track of the parent
        this.setCmp(grid);

        // the tool bar
        this.bbar = Ext.create('Ext.toolbar.Toolbar', {
            dock: 'bottom',
            items: [{
                itemId: 'counter',
                text: store.count(),
                xtype: 'tbtext'
            },
            this.textEntries,
            '->', {
                grid: grid,
                text: this.textPlus,
                xtype: 'xgridbuttonexpertmenu'
            }]
        });

        // insert the tool bar in the grid
        grid.insertDocked(0, this.bbar);

        // catch events to update the counter
        store.on('filterchange', this.updateCounter, this);
        store.on('load', this.updateCounter, this);
        store.on('write', this.updateCounter, this);
    },

    /**
     * destroy the plugin
     */
    destroy: function () {

        "use strict";
        var store = this.getCmp().getStore();

        store.un('filterchange', this.updateCounter, this);
        store.on('load', this.updateCounter, this);
        store.on('write', this.updateCounter, this);
    },

    /**
     * Update the total number of record displayed in the tool bar.
     */
    updateCounter: function () {

        "use strict";
        var store = this.getCmp().getStore();
        this.bbar.getComponent('counter').setText(store.count());
    }
});