/**
 * the plugin to render mathematics formula embedded in the HTML content.
 * The processing is performed by the [MathJax](http://www.mathjax.org/)
 * library.
 *
 */
Ext.define('App.panel.plugin.MathJax',  {

    extend: 'Ext.AbstractPlugin',
    alias: 'plugin.pPanelMathJax',

    /**
     * Initialize the plugin.
     *
     * @param {Ext.Panel} panel
     *
     */
    init: function (panel) {

        "use strict";

        // register an handler which is activated only once
        // when the panel is rendered for the first time
        panel.on('render', this.onPanelRender, this, {single: true});
    },

    /**
     * Activate the MathJax processing
     * when the HTML content of the panel is loaded.
     *
     * @param {Ext.Panel} panel
     */
    onPanelRender: function (panel) {
        "use strict";
        var updater = panel.body.getUpdater();
        updater.on('update', this.onProcess);
    },

    /**
     * Run the mathJax processing.
     *
     * @param {Ext.Element} el
     * @param {Object} o the response object
     */
    onProcess: function (e, o) {
        "use strict";
        MathJax.Hub.PreProcess();
        MathJax.Hub.Process();
    }
});