/**
 * The plugin to add login capabilities to the
 * {@link Ext.container.Viewport viewport}.
 *
 * The URLs:
 *
 *      Login           → /application/admin
 *      Change password → /application/default/user/change_password
 *      Logout          → /application/default/user/logout
 *
 * @uses App.viewport.Viewport
 *
 */
Ext.define('App.viewport.plugin.Login', {

    extend: 'Ext.AbstractPlugin',
    alias: 'plugin.pViewportLogin',

    // Private properties for internationalization
    textChangePwd: "Change password...",
    textLogin: "Login...",
    textLogout: "Exit the application",

    /**
     * Initialize the plugin.
     *
     * @param {App.viewport.Viewport} viewport
     */
    init: function (viewport) {

        "use strict";

        var inhibit_login = false,
            inhibit_logout = true,
            tbar = viewport.getComponent('topBar');

        if (viewport.logged) {
            inhibit_login = true;
            inhibit_logout = false;
        }

        tbar.add('->', '-');

        tbar.add({
            hidden: inhibit_login,
            href: "admin",
            handler: this.openURL,
            iconCls: 'xuser-identity',
            tooltip: this.textLogin
        });

        tbar.add({
            hidden: inhibit_logout,
            href: "default/user/change_password",
            handler: this.openURL,
            text: this.textChangePwd,
            scale: "small"
        });

        if (inhibit_login) {
            tbar.add('-');
        }

        tbar.add({
            hidden: inhibit_logout,
            href: "default/user/logout",
            handler: this.openURL,
            iconCls: 'xapplication-exit',
            tooltip: this.textLogout
        });

        tbar.setVisible(true);
    },

    /**
     * Open the URL in a new window.
     *
     * @param {Ext.button.Button} button
     * @param {String} button.href
     * The URL is relative to the application, e.g. "controller/function"
     *
     */
    openURL: function (button) {

        // NOTE
        // - use the browser object window and location
        // - to open the URL in a new window use window.open(url, "_blank")
        // - the button attribute href is defined by the code in the init

        "use strict";
        var url = location.protocol + "//" + location.host + "/" + App.name + "/";

        window.location = url + button.href;
    }
});